@@ -129,19 +129,9 @@ class AdminConnection(Protocol):
                 ))
 
             elif box.cmd in (
-                    constants.CMD_ADMIN_CHANGE,
                     constants.CMD_ADMIN_RELOAD,
                     constants.CMD_ADMIN_STOP,
             ):
-
-                if box.cmd == constants.CMD_ADMIN_CHANGE:
-                    # 修改配置，要把proxy里面的也修改了，否则reload workers会永远结束不了
-                    jdata = json.loads(box.body)
-                    if not self.factory.proxy.app.change_group_config(jdata['payload']['group_id'], jdata['payload']['count']):
-                        logger.error('change group config fail. proxy: %s, data: %s',
-                                     self.factory.proxy, box.body)
-                        return
-
                 if self.factory.proxy.master_conn and self.factory.proxy.master_conn.transport:
                     self.factory.proxy.master_conn.transport.write(box.pack())
 
