@@ -47,7 +47,7 @@ class Proxy(object):
         """
         self.app = app
 
-        self.task_dispatcher = TaskDispatcher(self, self._on_workers_reload_over)
+        self.task_dispatcher = TaskDispatcher(self)
         self.stat_counter = StatCounter(self.app.config['TASKS_TIME_BENCHMARK'])
 
     def run(self):
@@ -116,35 +116,13 @@ class Proxy(object):
 
         try:
             reactor.run(installSignalHandlers=False)
-        except KeyboardInterrupt:
-            pass
         except:
             logger.error('exc occur. proxy: %s', self, exc_info=True)
 
     def _handle_proc_signals(self):
-        def safe_reload_handler(signum, frame):
-            """
-            让所有子进程重新加载
-            """
-            self.task_dispatcher.start_reload()
-
-        # 直接结束
-        signal.signal(signal.SIGINT, reactor.sigInt)
         signal.signal(signal.SIGTERM, reactor.sigTerm)
-        # 忽略，因为这个时候是在重启worker
-        signal.signal(signal.SIGHUP, safe_reload_handler)
-
-    def _on_workers_reload_over(self):
-        """
-        当workers reload之后的操作
-        需要给master通知，让master替换掉workers
-        :return:
-        """
-        if self.master_conn and self.master_conn.transport:
-            box = Box(dict(
-                cmd=constants.CMD_MASTER_REPLACE_WORKERS
-            ))
-            self.master_conn.transport.write(box.pack())
+        signal.signal(signal.SIGINT, signal.SIG_IGN)
+        signal.signal(signal.SIGHUP, signal.SIG_IGN)
 
     def __repr__(self):
         return '<%s name: %s>' % (
